### Name: frailtyPenal for Shared frailty models
### Title: Fit Shared Gamma Frailty model using penalized likelihood
###   estimation
### Aliases: frailtyPenal 'frailtyPenal for Shared frailty models'
### Keywords: models

### ** Examples


 ###  Shared model  ###

data(kidney)
frailtyPenal(Surv(time,status)~ cluster(id)+sex+age,
             n.knots=12,kappa1=10000,data=kidney,Frailty=TRUE)

 ###  COX proportional hazard model (SHARED without frailties) ### 
 ### estimated with penalized likelihood ###

frailtyPenal(Surv(time,status)~sex+age+cluster(id),
             n.knots=12,kappa1=10000,data=kidney,Frailty=FALSE)

###  Shared model with truncated data ###

# Here is created a hypothetical truncated data
kidney$tt0<-rep(0,nrow(kidney))
kidney$tt0[1:3]<-c(2,9,13)

# then, we fit the model
frailtyPenal(Surv(tt0,time,status)~sex+age+cluster(id),
             n.knots=12,kappa1=10000,data=kidney,Frailty=TRUE)

###  Shared model - stratified analysis ###

data(readmission)
frailtyPenal(Surv(time,event)~as.factor(dukes)+cluster(id)+strata(sex),
             n.knots=10,kappa1=10000,kappa2=10000,data=readmission,Frailty=TRUE)

###  Shared model - recurrentAG=TRUE ###

frailtyPenal(Surv(t.start,t.stop,event)~as.factor(sex)+as.factor(dukes)+
             as.factor(charlson)+cluster(id),data=readmission, Frailty=TRUE,
             n.knots=6,kappa1=100000,recurrentAG=TRUE)

###  Shared model - cross.validation=TRUE ###

## Not run: 
##D  
##D frailtyPenal(Surv(t.start,t.stop,event)~as.factor(sex)+as.factor(dukes)+
##D              as.factor(charlson)+cluster(id),data=readmission, Frailty=TRUE,
##D              n.knots=6,kappa1=5000,recurrentAG=TRUE,cross.validation=TRUE)
## End(Not run)




